@@ -535,6 +535,7 @@ class ComponentContribution(object):
         self,
         reactions: List[PhasedReaction],
         uncertainty_representation: str = "cov",
+        minimize_norm: bool = False,
     ) -> Tuple[Q_, Q_]:
         """Calculate the transformed reaction energies of a list of reactions.
 
@@ -549,10 +550,14 @@ class ComponentContribution(object):
             'fullrank' would return a full-rank square root of the covariance
             which is a compressed form of the 'sqrt' result.
             (Default value: 'cov')
+        minimize_norm : bool
+            if True, use an orthogonal projection to minimize the norm2 of the
+            result vector (keeping it within the finite-uncertainty sub-space,
+            i.e. only moving along eigenvectors with infinite uncertainty).
 
         Returns
         -------
-        standard_dg : Quantity
+        standard_dg_prime : Quantity
             the CC estimation of the reactions' standard transformed energies
         dg_uncertainty : Quantity
             the uncertainty co-variance matrix
@@ -568,12 +573,12 @@ class ComponentContribution(object):
             reactions,
         )
         residual_reactions, stored_dg_primes = zip(*rxn_dg_pairs)
-        stored_dg_primes = np.array(stored_dg_primes)
 
         (standard_dg_prime, dg_uncertainty,) = self.predictor.standard_dg_multi(
             residual_reactions,
             uncertainty_representation=uncertainty_representation,
         )
+        standard_dg_prime += np.hstack(stored_dg_primes)
 
         # So far, standard_dg_prime is actually storing only the untransformed
         # standard ΔG. We must add the Legendre transform to each reaction to
@@ -592,7 +597,21 @@ class ComponentContribution(object):
                     + str(e)
                 )
 
-        standard_dg_prime += Q_(stored_dg_primes, "kJ/mol")
+        if minimize_norm:
+            # Calculate the residual matrix (X) that represents the DOFs that
+            # are completely free (infinite uncertianty).
+            _preprocessor = self.predictor.preprocess
+            X = _preprocessor.get_reaction_prediction_orthogonal_dof(
+                residual_reactions
+            )
+
+            # Project the 'standard_dg_prime' onto the nullspace of the
+            # residual matrix (using an orthogonal projection). This doesn't
+            # change the values in directions that are not complete DOFs, and
+            # at the same time minimizes the norm2 of the estimate vector.
+            _, _, _, P_N = LINALG.invert_project(X.T)
+            standard_dg_prime = P_N @ standard_dg_prime
+
         return standard_dg_prime, dg_uncertainty
 
     def physiological_dg_prime(
@@ -723,7 +742,7 @@ class ComponentContribution(object):
         self,
         reaction_inner: PhasedReaction,
         reaction_outer: PhasedReaction,
-        delta_chi: Q_,
+        e_potential_difference: Q_,
         p_h_outer: Q_,
         ionic_strength_outer: Q_,
         p_mg_outer: Q_ = default_physiological_p_mg,
@@ -739,19 +758,19 @@ class ComponentContribution(object):
             the inner compartment half-reaction
         reaction_outer : PhasedReaction
             the outer compartment half-reaction
-        delta_phi : Q_
+        e_potential_difference : Quantity
             the difference in electro-static potential between
             the outer and inner compartments
-        p_h_outer : Q_
+        p_h_outer : Quantity
             the pH in the outside compartment
-        ionic_strength_outer : Q_
+        ionic_strength_outer : Quantity
             the ionic strength outside
-        p_mg_outer : Q_
+        p_mg_outer : Quantity (optional)
             the pMg in the outside compartment
 
         Returns
         -------
-        standard_dg_prime : ureg.Measurement
+        standard_dg_prime : Measurement
             the transport reaction Gibbs free energy change
         """
 
@@ -809,16 +828,18 @@ class ComponentContribution(object):
         )
 
         (standard_dg) = self.predictor.multicompartmental_standard_dg_prime(
-            residual_reaction_inner,
-            residual_reaction_outer,
-            transported_protons,
-            transported_charge,
-            self.p_h,
-            p_h_outer,
-            self.ionic_strength,
-            ionic_strength_outer,
-            delta_chi,
-            self.temperature,
+            reaction_1=residual_reaction_inner,
+            reaction_2=residual_reaction_outer,
+            transported_protons=transported_protons,
+            transported_charge=transported_charge,
+            p_h_1=self.p_h,
+            p_h_2=p_h_outer,
+            ionic_strength_1=self.ionic_strength,
+            ionic_strength_2=ionic_strength_outer,
+            e_potential_difference=e_potential_difference,
+            temperature=self.temperature,
+            p_mg_1=self.p_mg,
+            p_mg_2=p_mg_outer,
         )
 
         return standard_dg + stored_dg_prime_inner + stored_dg_prime_outer
@@ -848,86 +869,3 @@ class ComponentContribution(object):
             self.ccache.is_water,
             self.ccache.water,
         )
-
-    # DISCLAIMER: this is experimental code!
-    def _standard_dg_prime_multi_adjust_dof(
-        self,
-        reactions: List[PhasedReaction],
-        uncertainty_representation: str = "cov",
-    ) -> Tuple[np.array, np.array]:
-        """Calculate the transformed reaction energies of a list of reactions.
-
-        Adjusts the estimates by using the Degrees Of Freedom
-        associated with the CC nullspace to minimize the norm2 of the
-        standard reaction energies - using Least Squares.
-
-
-        Parameters
-        ----------
-        reactions : List[PhasedReaction]
-            a list of PhasedReaction objects to estimate
-        uncertainty_representation : str
-            which representation to use for the uncertainties. 'cov' would
-            return a full covariance matrix. 'sqrt' would return a sqaure root
-            of the covariance, based on the uncertainty vectors.
-            'fullrank' would return a full-rank square root of the covariance
-            which is a compressed form of the 'sqrt' result.
-            (Default value: 'cov')
-
-        Returns
-        -------
-        standard_dg : Quantity
-            the CC estimation of the reactions' standard transformed energies
-        dg_uncertainty : Quantity
-            the uncertainty co-variance matrix
-            (in either 'cov', 'sqrt' or 'fullrank' format)
-        """
-        rxn_dg_pairs = map(
-            lambda r: r.separate_stored_dg_prime(
-                p_h=self.p_h,
-                p_mg=self.p_mg,
-                ionic_strength=self.ionic_strength,
-                temperature=self.temperature,
-            ),
-            reactions,
-        )
-        residual_reactions, stored_dg_primes = zip(*rxn_dg_pairs)
-
-        (standard_dg_prime, dg_uncertainty,) = self.predictor.standard_dg_multi(
-            residual_reactions,
-            uncertainty_representation=uncertainty_representation,
-        )
-
-        # So far, standard_dg_prime is actually storing only the untransformed
-        # standard ΔG. We must add the Legendre transform to each reaction to
-        # get the standard ΔG.
-        for i, r in enumerate(residual_reactions):
-            try:
-                standard_dg_prime[i] += r.transform(
-                    p_h=self.p_h,
-                    p_mg=self.p_mg,
-                    ionic_strength=self.ionic_strength,
-                    temperature=self.temperature,
-                )
-            except MissingDissociationConstantsException as e:
-                warnings.warn(
-                    f"Cannot calculate Legendre transform for reaction #{i}: "
-                    + str(e)
-                )
-
-        standard_dg_prime += Q_(stored_dg_primes, "kJ/mol")
-
-        # Calculate the residual matrix (X) that represents the DOFs that are
-        # completely free (infinite uncertianty).
-        X = self.predictor.preprocess.get_reaction_prediction_orthogonal_dof(
-            residual_reactions
-        )
-
-        # Project the 'standard_dg_prime' onto the nullspace of the residual
-        # matrix (using an orthogonal projection). This doesn't change the
-        # values in directions that are not complete DOFs, and at the same
-        # time minimizes the norm2 of the estimate vector.
-        _, _, _, P_N = LINALG.invert_project(X.T)
-        standard_dg_prime = P_N @ standard_dg_prime
-
-        return standard_dg_prime, dg_uncertainty
